@@ -3,6 +3,7 @@
 "Work"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
+from trytond.pyson import PYSONEncoder
 
 
 class Work(ModelSQL, ModelView):
@@ -17,8 +18,8 @@ class Work(ModelSQL, ModelView):
     left = fields.Integer('Left', required=True, select=1)
     right = fields.Integer('Right', required=True, select=1)
     children = fields.One2Many('timesheet.work', 'parent', 'Children')
-    hours = fields.Function('get_hours', digits=(16, 2),
-            string='Timesheet Hours', help="Total time spent on this work")
+    hours = fields.Function(fields.Float('Timesheet Hours', digits=(16, 2),
+        help="Total time spent on this work"), 'get_hours')
     timesheet_available = fields.Boolean('Available on timesheets',
             help="Allow to fill in timesheets with this work")
     company = fields.Many2One('company.company', 'Company', required=True)
@@ -70,7 +71,7 @@ class Work(ModelSQL, ModelView):
                 to_compute[h] = False
         return res
 
-    def get_hours(self, cursor, user, ids, name, arg, context=None):
+    def get_hours(self, cursor, user, ids, name, context=None):
         all_ids = self.search(cursor, user, [
                 ('parent', 'child_of', ids)
                 ], context=context)
@@ -101,7 +102,7 @@ class Work(ModelSQL, ModelView):
         self._tree_qty(hours_by_wt, children, ids, to_compute)
         return hours_by_wt
 
-    def get_rec_name(self, cursor, user, ids, name, arg, context=None):
+    def get_rec_name(self, cursor, user, ids, name, context=None):
         if not ids:
             return {}
         res = {}
@@ -166,16 +167,10 @@ class OpenWork(Wizard):
     def _action_open_work(self, cursor, user, data, context=None):
         model_data_obj = self.pool.get('ir.model.data')
         act_window_obj = self.pool.get('ir.action.act_window')
-
-        model_data_ids = model_data_obj.search(cursor, user, [
-            ('fs_id', '=', 'act_work_tree2'),
-            ('module', '=', 'timesheet'),
-            ('inherit', '=', False),
-            ], limit=1, context=context)
-        model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
-                context=context)
-        res = act_window_obj.read(cursor, user, model_data.db_id, context=context)
-        res['context'] = str({
+        act_window_id = model_data_obj.get_id(cursor, user, 'timesheet',
+                'act_work_tree2', context=context)
+        res = act_window_obj.read(cursor, user, act_window_id, context=context)
+        res['pyson_context'] = PYSONEncoder().encode({
             'from_date': data['form']['from_date'],
             'to_date': data['form']['to_date'],
             })
@@ -190,16 +185,10 @@ class OpenWork2(OpenWork):
     def _action_open_work(self, cursor, user, data, context=None):
         model_data_obj = self.pool.get('ir.model.data')
         act_window_obj = self.pool.get('ir.action.act_window')
-
-        model_data_ids = model_data_obj.search(cursor, user, [
-            ('fs_id', '=', 'act_work_form2'),
-            ('module', '=', 'timesheet'),
-            ('inherit', '=', False),
-            ], limit=1, context=context)
-        model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
-                context=context)
-        res = act_window_obj.read(cursor, user, model_data.db_id, context=context)
-        res['context'] = str({
+        act_window_id = model_data_obj.get_id(cursor, user, 'timesheet',
+                'act_work_form2', context=context)
+        res = act_window_obj.read(cursor, user, act_window_id, context=context)
+        res['pyson_context'] = PYSONEncoder().encode({
             'from_date': data['form']['from_date'],
             'to_date': data['form']['to_date'],
             })
@@ -228,14 +217,9 @@ class OpenWorkGraph(Wizard):
         if context is None:
             context = {}
 
-        model_data_ids = model_data_obj.search(cursor, user, [
-            ('fs_id', '=', 'act_work_form3'),
-            ('module', '=', 'timesheet'),
-            ('inherit', '=', False),
-            ], limit=1, context=context)
-        model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
-                context=context)
-        res = act_window_obj.read(cursor, user, model_data.db_id, context=context)
+        act_window_id = model_data_obj.get_id(cursor, user, 'timesheet',
+                'act_work_form3', context=context)
+        res = act_window_obj.read(cursor, user, act_window_id, context=context)
         if 'active_id' in context:
             work = work_obj.browse(cursor, user, context['active_id'],
                     context=context)
